@@ -18,9 +18,14 @@ CIF2.CR <- function(data, H01, H02, s, u, bl) {
   CIF2 <- 0
   for (i in 1:b) {
     if (s <= H02[i, 1] & u >= H02[i, 1]) {
-      CIF2 <- CIF2 + H02[i, 3]*exp(data$X2%*%data$gamma2 + data$nu2%*%bl)*
-        exp(-CH01[i]*exp(data$X2%*%data$gamma1 + data$nu1%*%bl)-
-              CH02[i]*exp(data$X2%*%data$gamma2 + data$nu2%*%bl))
+      if (i >= 2) {
+        CIF2 <- CIF2 + H02[i, 3]*exp(data$X2%*%data$gamma2 + data$nu2%*%bl)*
+          exp(-CH01[i-1]*exp(data$X2%*%data$gamma1 + data$nu1%*%bl)-
+                CH02[i-1]*exp(data$X2%*%data$gamma2 + data$nu2%*%bl))
+      } else {
+        CIF2 <- CIF2 + H02[i, 3]*exp(data$X2%*%data$gamma2 + data$nu2%*%bl)
+      }
+
       
     } else next
   }
