@@ -26,7 +26,7 @@ Rcpp::List getCov(const Eigen::VectorXd & beta, const Eigen::VectorXd & gamma1,
   int b = H02.rows();
   int k = mdata.size();
   
-  int i,p,q,j,t,u;
+  int i,q,j,t;
   
   double temp,temp1;
   
@@ -64,7 +64,6 @@ Rcpp::List getCov(const Eigen::VectorXd & beta, const Eigen::VectorXd & gamma1,
   }
   
   double epsilon=0;
-  double qq=0;
   double qqsigma=0;
   int p1 = beta.size();
   int p1a = Z.cols();
